@@ -6,6 +6,8 @@
 
 import collections, urlparse
 
+from learnsprout.errors import error_from_json
+
 class Resource(object):
   """
     **Resource** is a base class for all resources available on the REST API.
@@ -146,6 +148,9 @@ class IterableResult(object):
         parameters["offset"] = self.__next
 
       response = self.client.make_request(self.uri, parameters)
+      if "status_code" in response and response["status_code"] >= 400:
+        raise error_from_json(response)
+
       if "data" in response and "next" in response: # Paginated collection
         if response["next"]:
           parse = urlparse.urlparse(response["next"])
